% Espera que os motores terminem o movimento
%
% [stat,error,errorstr]=motionstart(H,scuid)
%
% H: Handler de comunicações
% scuid: Endereços a testar
%
% stat: Verdadeiro se os motores terminaram o movimento
% error: Flag de erro
% errorstr: String de erro

function [stat,error,errorstr]=motionfin(H,scuid)

% Estado de sucesso da operação
stat=0;
error=0;
errorstr='OK';

% Timeout para terminar o movimento
timeout=10;

% Espera que os motores terminem o movimento
finall=0;
tic
while (finall==0 && toc<timeout)
    [finall,x,x,x,error,errorstr]=statmotionfin(H,scuid);
    if (error==1), return, end
end

% Os motores efectivamente terminaram o movimento?
stat=finall;